@@ -52,10 +52,11 @@ class Miriad(UVData):
         read_data=True,
         phase_type=None,
         correct_lat_lon=True,
+        background_lsts=True,
         run_check=True,
         check_extra=True,
         run_check_acceptability=True,
-        background_lsts=True,
+        strict_uvw_antpos_check=False,
     ):
         """
         Read in data from a miriad file.
@@ -105,6 +106,8 @@ class Miriad(UVData):
         correct_lat_lon : bool
             Option to update the latitude and longitude from the known_telescopes
             list if the altitude is missing.
+        background_lsts : bool
+            When set to True, the lst_array is calculated in a background thread.
         run_check : bool
             Option to check for the existence and proper shapes of parameters
             after after reading in the file (the default is True,
@@ -117,8 +120,9 @@ class Miriad(UVData):
             Option to check acceptable range of the values of parameters after
             reading in the file (the default is True, meaning the acceptable
             range check will be done). Ignored if read_data is False.
-        background_lsts : bool
-            When set to True, the lst_array is calculated in a background thread.
+        strict_uvw_antpos_check : bool
+            Option to raise an error rather than a warning if the check that
+            uvws match antenna positions does not pass.
 
         Raises
         ------
@@ -708,16 +712,19 @@ class Miriad(UVData):
         # check if object has all required uv_properties set
         if run_check:
             self.check(
-                check_extra=check_extra, run_check_acceptability=run_check_acceptability
+                check_extra=check_extra,
+                run_check_acceptability=run_check_acceptability,
+                strict_uvw_antpos_check=strict_uvw_antpos_check,
             )
 
     def write_miriad(
         self,
         filepath,
+        clobber=False,
         run_check=True,
         check_extra=True,
         run_check_acceptability=True,
-        clobber=False,
+        strict_uvw_antpos_check=False,
         no_antnums=False,
     ):
         """
@@ -727,6 +734,8 @@ class Miriad(UVData):
         ----------
         filename : str
             The miriad root directory to write to.
+        clobber : bool
+            Option to overwrite the filename if the file already exists.
         run_check : bool
             Option to check for the existence and proper shapes of parameters
             after before writing the file (the default is True,
@@ -738,8 +747,9 @@ class Miriad(UVData):
             Option to check acceptable range of the values of parameters before
             writing the file (the default is True, meaning the acceptable
             range check will be done).
-        clobber : bool
-            Option to overwrite the filename if the file already exists.
+        strict_uvw_antpos_check : bool
+            Option to raise an error rather than a warning if the check that
+            uvws match antenna positions does not pass.
         no_antnums : bool
             Option to not write the antnums variable to the file.
             Should only be used for testing purposes.
@@ -773,6 +783,7 @@ class Miriad(UVData):
                 check_extra=check_extra,
                 run_check_acceptability=run_check_acceptability,
                 check_freq_spacing=True,
+                strict_uvw_antpos_check=strict_uvw_antpos_check,
             )
 
         # check for multiple spws
